## Info

Name: superior6564

Version: 0.2.2

Description: Python library which maybe will help to people. Before using you need to run packages.required()

Home-page: https://github.com/Superior-GitHub/Superior6564

Download-URL: https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip

Wiki: https://github.com/Superior-GitHub/superior6564/wiki

Author: Superior_6564

Author-email: vip.klochayil@gmail.com

License: Apache License, Version 2.0, see LICENSE file

## Installation

Install the current version with PyPI:

pip install superior6564

Or from Github:

pip install https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip

## Usage

Before using you need to run packages.required()

It will check for the necessary libraries and install them if needed.

## Contributing

Bug reports and/or pull requests are welcome

## License 

The module is available as open source under the terms of the [Apache License, Version 2.0](https://opensource.org/licenses/Apache-2.0)
